@@ -1,37 +1,39 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ * 
+ *  http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
  */
 package org.apache.myfaces.shared_impl.util;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
-import javax.faces.application.FacesMessage;
-import javax.faces.application.ApplicationFactory;
-import javax.faces.application.Application;
-import javax.faces.context.FacesContext;
-import javax.faces.FactoryFinder;
-
 import java.text.MessageFormat;
 import java.util.Locale;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
+import javax.el.ValueExpression;
+import javax.faces.FactoryFinder;
+import javax.faces.application.Application;
+import javax.faces.application.ApplicationFactory;
+import javax.faces.application.FacesMessage;
+import javax.faces.component.UIComponent;
+import javax.faces.context.FacesContext;
+
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 /**
  * Utility class to support multilingual FacesMessages using ResourceBundles.
  * Standard messages are stored at <code>DEFAULT_BUNDLE</code>.<br>
@@ -45,7 +47,7 @@ import java.util.ResourceBundle;
  * @author Manfred Geiler
  * @author Sean Schofield
  * @author Stpehan Strittmatter
- * @version $Revision: 940132 $ $Date: 2010-05-01 20:29:23 -0500 (Sat, 01 May 2010) $
+ * @version $Revision: 940133 $ $Date: 2010-05-01 20:30:31 -0500 (Sat, 01 May 2010) $
  */
 public final class MessageUtils
 {
@@ -599,6 +601,19 @@ public final class MessageUtils
             return getMessageFromBundle(bundleBaseName, context, locale, messageId, params);
         }
     }
+    
+    public static Object getLabel(FacesContext facesContext, UIComponent component) {
+        Object label = component.getAttributes().get("label");
+        if(label != null)
+            return label;
+        
+        ValueExpression expression = component.getValueExpression("label");
+        if(expression != null)
+            return expression;
+        
+        //If no label is not specified, use clientId
+        return component.getClientId( facesContext );
+    }
 
     private static Application getApplication()
     {
